.token-table-container{font-family:Roboto,sans-serif;overflow-x:auto;width:100%}.token-table{border-collapse:initial;border-radius:8px;border-spacing:0;box-shadow:0 2px 5px #0003;margin-top:20px;overflow:hidden;width:100%}td,th{border-bottom:1px solid #eaeaea;font-size:.95em;padding:12px 15px;text-align:left}th{position:relative}button{border:none;border-radius:4px;cursor:pointer;font-size:.85em;margin-right:5px;padding:8px 12px;transition:background-color .3s ease}button.delete-button{background-color:initial;color:#bbb;font-size:.75em;padding:4px}button.delete-button:hover{color:#ff4757}input[type=text]{border:1px solid #ddd;border-radius:4px;box-sizing:border-box;padding:8px;width:100%}.cancel-button,.confirm-delete-button{border:none;border-radius:4px;color:#fff;cursor:pointer;font-size:.7em;font-weight:700;margin-right:5px;padding:5px 7px;transition:background-color .3s ease}.confirm-delete-button{background-color:#ff4757}.confirm-delete-button:hover{background-color:#ff6b81}.cancel-button{background-color:#576574}.cancel-button:hover{background-color:#6c757d}.action-cell{white-space:nowrap}.fa-trash{color:inherit;font-size:.9em}button.delete-button .fa-trash{transition:color .3s ease}td[data-tooltip]:hover:after,th[data-tooltip]:hover:after{background-color:#555;border-radius:2px;color:#fff;content:attr(data-tooltip);font-size:.7em;left:50%;padding:2px 6px;pointer-events:none;position:absolute;top:100%;transform:translateX(-50%) translateY(4px);white-space:nowrap;z-index:1000}
/*# sourceMappingURL=main.794b5503.css.map*/